package app.scanfood.tfm.scanfood.scanner

import android.content.Context
import android.hardware.camera2.CameraCharacteristics
import android.hardware.camera2.CameraMetadata
import android.view.View
import androidx.lifecycle.DefaultLifecycleObserver
import androidx.lifecycle.LifecycleOwner
import app.scanfood.tfm.scanfood.helpers.LifecycleProvider
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.platform.PlatformView
import uk.co.brightec.kbarcode.Barcode
import uk.co.brightec.kbarcode.BarcodeView
import uk.co.brightec.kbarcode.Options
import uk.co.brightec.kbarcode.processor.OnBarcodeListener

class NativeScannerView(
        private val context: Context,
        id: Int,
        creationParams: Map<String?, Any?>?,
        private val lifecycleProvider: LifecycleProvider,
        binaryMessenger: BinaryMessenger
    ): DefaultLifecycleObserver, PlatformView, EventChannel.StreamHandler {
    private val barcodeView: BarcodeView = BarcodeView(context)
    private val eventChannel = EventChannel(binaryMessenger,
        creationParams?.get("event_channel_id") as String
    )
    private var eventSink: EventChannel.EventSink? = null
    private val methodChannel = MethodChannel(binaryMessenger,
        creationParams?.get("method_channel_id") as String
    );

    init {
        eventChannel.setStreamHandler(this)
        methodChannel.invokeMethod("event_channel_ready", null);
        lifecycleProvider.getLifecycle()?.addObserver(this);

        barcodeView.setOptions(
                Options.Builder()
                        .cameraFacing(CameraCharacteristics.LENS_FACING_BACK)
                        .cameraFlashMode(CameraMetadata.FLASH_MODE_OFF)
                        .barcodeFormats(
                                intArrayOf(
                                       Barcode.FORMAT_EAN_13, Barcode.FORMAT_EAN_8
                                )
                        )
                        .barcodesSort(null)
                        .previewScaleType(BarcodeView.CENTER_CROP)
                        .clearFocusDelay(BarcodeView.CLEAR_FOCUS_DELAY_DEFAULT)
                        .build()
        )
    }

    override fun onCreate(owner: LifecycleOwner) {
        super.onCreate(owner)

        barcodeView.start()

        barcodeView.onBarcodeListener = OnBarcodeListener { barcode ->
            if(barcode.rawValue != null) {
                eventSink?.success(barcode.rawValue)
            }
        }
    }

    override fun onPause(owner: LifecycleOwner) {
        super.onPause(owner)

        barcodeView.pause()
    }

    override fun onResume(owner: LifecycleOwner) {
        super.onResume(owner)
        barcodeView.resume()
    }

    override fun getView(): View {
        return barcodeView
    }

    override fun dispose() {
        lifecycleProvider.getLifecycle()?.removeObserver(this)
        eventChannel.setStreamHandler(null);
    }

    override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
        eventSink = events;
    }

    override fun onCancel(arguments: Any?) {
        eventSink = null
        barcodeView.onBarcodeListener = null
    }
}