//
//  VisionBarcodeDetector.swift
//  Runner
//
//  Created by Sergio Durban Belmonte on 29/11/21.
//

import Foundation
import Vision

typealias CallbackBarcode = ((String) -> Void)

class VisionBarcodeDetector {
    private let sequenceHandler = VNSequenceRequestHandler()
    
    private func completeImageRequest(
        for frame: CVImageBuffer,
        completion: CallbackBarcode
    ) {
        let barcodeDetectionRequest: VNDetectBarcodesRequest = {
            let barcodeDetectRequest = VNDetectBarcodesRequest()
            
            barcodeDetectRequest.symbologies = [.ean8, .ean13]
            
            return barcodeDetectRequest
        }()
        
        try? self.sequenceHandler.perform([barcodeDetectionRequest], on: frame)
        guard let firstBarcode = barcodeDetectionRequest.results?.first?.payloadStringValue else {
            return
        }
        
        completion(firstBarcode)
    }
    
    func barcode(forPixelBuffer pixelBuffer: CVImageBuffer, completion: CallbackBarcode) {
        self.completeImageRequest(for: pixelBuffer, completion: completion)
    }
}

