//
//  NativeScannerPlatformViewFactory.swift
//  Runner
//
//  Created by Sergio Durban Belmonte on 29/11/21.
//

import Foundation

final class CameraPhotoPlatformView: NSObject, FlutterPlatformView, NativeScannerViewDelegate {
    let frame: CGRect
    let viewId: Int64
    let _view: NativeScannerView

    let nativeScannerStream: NativeScannerStream?

    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        binaryMessenger messenger: FlutterBinaryMessenger,
        withMethodChannelId methodChannelId: String?,
        andEventChannelId eventChannelId: String?
    ) {
        self.frame = frame
        self.viewId = viewId
        _view = NativeScannerView(frame: frame)
        guard let methodChannelId = methodChannelId,
              let eventChannelId = eventChannelId else {
            nativeScannerStream = nil

            super.init()

            return
        }

        let eventChannel = FlutterEventChannel(name: eventChannelId, binaryMessenger: messenger)
        nativeScannerStream = NativeScannerStream()
        eventChannel.setStreamHandler(nativeScannerStream)

        let channel = FlutterMethodChannel(name: methodChannelId, binaryMessenger: messenger)

        channel.invokeMethod("event_channel_ready", arguments: nil)
        
        _view.startReader()
        
        _view.backgroundColor = UIColor(displayP3Red: 0, green: 0, blue: 0, alpha: 1)

        super.init()
        
        _view.delegate = self
    }

    func view() -> UIView {
        return _view
    }

    func barcodeOutput(string: String?) {
        if let string = string {
            nativeScannerStream?.sendBarcode(string)
        }
    }
}
