//
//  NativeScannerPlatformViewFactory.swift
//  Runner
//
//  Created by Sergio Durban Belmonte on 29/11/21.
//

import Foundation

final class NativeScannerPlatformViewFactory: NSObject, FlutterPlatformViewFactory {
    
    private let messenger: FlutterBinaryMessenger
    
    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
        super.init()
    }
    
    // Pragma: Register Factory
    public static func register(with registrar: FlutterPluginRegistrar) {
        registrar.register(
            NativeScannerPlatformViewFactory(messenger: registrar.messenger()),
            withId: "scanfood/native-scanner/view"
        )
    }
    
    func create(withFrame frame: CGRect, viewIdentifier viewId: Int64, arguments args: Any?) -> FlutterPlatformView {
        let arguments = args as? NSDictionary
        let methodChannel = arguments?["method_channel_id"] as? String
        let eventChannel = arguments?["event_channel_id"] as? String
        
        return CameraPhotoPlatformView(
            frame: frame,
            viewIdentifier: viewId,
            binaryMessenger: messenger,
            withMethodChannelId: methodChannel,
            andEventChannelId: eventChannel
        )
    }
    
    public func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
        return FlutterStandardMessageCodec.sharedInstance()
    }
}
