import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:flutter/foundation.dart';
import 'package:scanfood/domain/model/objects/product.dart';

part 'list_state.dart';

abstract class ListCubit extends Cubit<ListState> {
  @protected
  final bool loading;

  @protected
  final bool userHasSearched;

  @protected
  final Set<Product> products;

  @protected
  final Set<Allergens> disabledAllergens;

  ListCubit(
    this.loading,
    this.products,
    this.userHasSearched,
    this.disabledAllergens,
  ) : super(ListState(
            products: products,
            userHasSearched: userHasSearched,
            disabledAllergens: disabledAllergens,
            loading: loading));

  void addFilterToAllergens(Allergens allergens) {
    disabledAllergens.add(allergens);

    emit(
      ListState(
          products:
              products.where((element) => element.allergens.toSet().intersection(disabledAllergens).isEmpty).toSet(),
          disabledAllergens: disabledAllergens,
          userHasSearched: userHasSearched,
          loading: loading),
    );
  }

  void removeFiltertoAllergens(Allergens allergens) {
    disabledAllergens.remove(allergens);

    emit(
      ListState(
          products:
              products.where((element) => element.allergens.toSet().intersection(disabledAllergens).isEmpty).toSet(),
          disabledAllergens: disabledAllergens,
          userHasSearched: userHasSearched,
          loading: loading),
    );
  }
}
