import 'dart:async';

import 'package:injectable/injectable.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:scanfood/domain/repository/onboarding_status_repository.dart';
import 'package:scanfood/domain/service/check_platform_device.dart';
import 'package:scanfood/ui/main_screen/main_screen.dart';
import 'package:scanfood/ui/onboarding_screen/onboarding_screen.dart';

@injectable
class ApplicationStartupService {
  final OnboardingStatusRepository _onboardingStatusRepository;
  final CheckPlatformDevice _checkPlatformDevice;
  final Permission _appTrackingTransparency;

  ApplicationStartupService(
    this._onboardingStatusRepository,
    this._checkPlatformDevice,
    @Named('appTrackingTransparency') this._appTrackingTransparency,
  );

  Future<String> execute() async {
    if (_checkPlatformDevice.isIos && !(await _appTrackingTransparency.isPermanentlyDenied)) {
      await _appTrackingTransparency.request();
    }

    String route = MainScreen.ROUTE;

    if (await _onboardingStatusRepository.hasToShowOnboarding()) {
      route = OnboardingScreen.ROUTE;
    }

    return route;
  }
}
