import 'dart:async';

import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:scanfood/core/services/core_navigator_service.dart';
import 'package:scanfood/core/services/core_startup_service.dart';

typedef PostInitDecisionFunction = FutureOr<String> Function();

class SplashHolder extends StatelessWidget {
  final CoreNavigatorService _coreNavigatorService;
  final CoreStartupService _coreStartupService;
  final String failedRoute;
  final Widget splashWidget;
  final PostInitDecisionFunction postInitDecisionFunction;

  SplashHolder({
    Key? key,
    required this.failedRoute,
    required this.splashWidget,
    required this.postInitDecisionFunction,
    CoreNavigatorService? coreNavigatorService,
    CoreStartupService? startupService,
  })  : _coreNavigatorService = coreNavigatorService ?? GetIt.I.get<CoreNavigatorService>(),
        _coreStartupService = startupService ?? GetIt.I.get<CoreStartupService>(),
        super(key: key) {
    WidgetsBinding.instance!.addPostFrameCallback(_startupApp);
  }

  void _startupApp(Duration timeStamp) async {
    try {
      await Future.wait([
        _coreStartupService.execute(),
        Future.delayed(const Duration(milliseconds: 100)),
      ]);

      final FutureOr<String> routeOr = postInitDecisionFunction();
      if (routeOr is Future<String>) {
        final route = await routeOr;
        _coreNavigatorService.pushReplacementNamed(route);
      } else {
        _coreNavigatorService.pushReplacementNamed(routeOr);
      }
    } catch (_) {
      _coreNavigatorService.pushReplacementNamed(failedRoute);
    }
  }

  @override
  Widget build(BuildContext context) {
    return splashWidget;
  }
}
