import 'package:equatable/equatable.dart';
import 'package:scanfood/domain/model/value_objects/barcode.dart';

enum NutrientLevel { unknown, low, medium, high }

enum EcoScoreLevel { unknown, A, B, C, D, E }

enum NutriScoreLevel { unknown, A, B, C, D, E }

enum NOVALevel { unknown, A, B, C, D }

enum Allergens {
  lupin,
  celery,
  peanuts,
  crustaceans,
  sulphur_dioxide_and_sulphites,
  nuts,
  gluten,
  sesame_seeds,
  eggs,
  milk,
  molluscs,
  fish,
  soybeans,
}

class Product extends Equatable {
  final String _productName;
  final String _brand;
  final String _quantity;
  final Barcode _barcode;
  final NutrientLevel _sugarsLevel;
  final NutrientLevel _fatLevel;
  final NutrientLevel _saturatedFatLevel;
  final NutrientLevel _saltLevel;
  final EcoScoreLevel _ecoScoreLevel;
  final NutriScoreLevel _nutriScoreLevel;
  final NOVALevel _nova;
  final List<Allergens> _allergens;
  final String _imageUrl;
  final double? _salt;
  final double? _fat;
  final double? _saturatedFat;
  final double? _sugars;

  Product({
    required String productName,
    required String brand,
    required String quantity,
    required Barcode barcode,
    required NutrientLevel sugarsLevel,
    required NutrientLevel fatLevel,
    required NutrientLevel saturatedFatLevel,
    required NutrientLevel saltLevel,
    required EcoScoreLevel ecoScoreLevel,
    required NutriScoreLevel nutriScoreLevel,
    required NOVALevel nova,
    required List<Allergens> allergens,
    required String imageUrl,
    required double? salt,
    required double? fat,
    required double? saturatedFat,
    required double? sugars,
  })  : _productName = productName,
        _brand = brand,
        _quantity = quantity,
        _barcode = barcode,
        _sugarsLevel = sugarsLevel,
        _fatLevel = fatLevel,
        _saturatedFatLevel = saturatedFatLevel,
        _saltLevel = saltLevel,
        _ecoScoreLevel = ecoScoreLevel,
        _nutriScoreLevel = nutriScoreLevel,
        _nova = nova,
        _allergens = allergens,
        _imageUrl = imageUrl,
        _salt = salt,
        _saturatedFat = saturatedFat,
        _fat = fat,
        _sugars = sugars;

  String get quantity => _quantity;

  String get brand => _brand;

  String get productName => _productName;

  Barcode get barcode => _barcode;

  NutrientLevel get sugarsLevel => _sugarsLevel;

  NutrientLevel get fatLevel => _fatLevel;

  NutrientLevel get saturatedFatLevel => _saturatedFatLevel;

  NutrientLevel get saltLevel => _saltLevel;

  EcoScoreLevel get ecoScoreLevel => _ecoScoreLevel;

  NutriScoreLevel get nutriScoreLevel => _nutriScoreLevel;

  NOVALevel get nova => _nova;

  List<Allergens> get allergens => _allergens;

  String get imageUrl => _imageUrl;

  double? get salt => _salt;

  double? get fat => _fat;

  double? get saturatedFat => _saturatedFat;

  double? get sugars => _sugars;

  @override
  List<Object?> get props => [
        _productName,
        _brand,
        _barcode,
        _sugarsLevel,
        _fatLevel,
        _saturatedFatLevel,
        _saltLevel,
        _ecoScoreLevel,
        _nutriScoreLevel,
        _nova,
        _allergens,
        _imageUrl,
        _fat,
        _saturatedFat,
        _sugars,
        _salt,
      ];
}
