import 'package:injectable/injectable.dart';
import 'package:scanfood/domain/errors/no_product_found_error.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/domain/model/value_objects/barcode.dart';
import 'package:scanfood/domain/repository/product_repository.dart';
import 'package:scanfood/infrastructure/repository/hive/hive_product_repository.dart';
import 'package:scanfood/infrastructure/repository/open_food_facts_product_repository.dart';

@Injectable(as: ProductRepository)
class CachedProductRepository implements ProductRepository {
  final HiveProductRepository _hiveProductRepository;
  final OpenFoodFactsProductRepository _openFoodFactsProductRepository;

  const CachedProductRepository(
    this._hiveProductRepository,
    this._openFoodFactsProductRepository,
  );

  @override
  Future<Product> findProductByBarcode(Barcode barcode) async {
    late Product p;

    try {
      p = await _hiveProductRepository.findProductByBarcode(barcode);
    } on NoProductFoundError catch (_) {
      p = await _openFoodFactsProductRepository.findProductByBarcode(barcode);

      await _hiveProductRepository.saveProduct(p);
    }

    return p;
  }

  @override
  Future<List<Product>> getAll() => _hiveProductRepository.getAll();

  @override
  Future<List<Product>> searchByText(String text) async => _openFoodFactsProductRepository.searchByText(text);
}
