import 'package:flutter/services.dart';
import 'package:uuid/uuid.dart';

typedef CallbackListen = Function();

class NativeScannerController {
  static const METHOD_CHANNEL_NAME = 'scanfood/native-scanner/actions';
  final EventChannel _eventChannel;
  final MethodChannel _methodChannel;
  final CallbackListen _callbackListen;

  NativeScannerController({required CallbackListen callbackListen, String? channelId})
      : _callbackListen = callbackListen,
        _methodChannel = MethodChannel('$METHOD_CHANNEL_NAME/${channelId ?? Uuid().v1()}'),
        _eventChannel = EventChannel('$METHOD_CHANNEL_NAME/${channelId ?? Uuid().v1()}') {
    _methodChannel.setMethodCallHandler(_nativeCallbacks);
  }

  Future<void> _nativeCallbacks(MethodCall call) async {
    switch (call.method) {
      case 'event_channel_ready':
        _callbackListen.call();
        break;
      default:
        throw UnimplementedError();
    }
  }

  String get channelName => _methodChannel.name;
  String get eventChannelName => _eventChannel.name;
  Stream get barcodeStream => _eventChannel.receiveBroadcastStream();
}
