import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class NativeScannerView extends StatefulWidget {
  static const viewType = 'scanfood/native-scanner/view';
  final String methodChannelId;
  final String eventChannelId;

  const NativeScannerView({
    Key? key,
    required this.methodChannelId,
    required this.eventChannelId,
  }) : super(key: key);

  @override
  State<NativeScannerView> createState() => _NativeScannerViewState();
}

class _NativeScannerViewState extends State<NativeScannerView> {
  bool _loadedView = false;

  void animationTransitionEnded() {
    Future.delayed(const Duration(milliseconds: 250)).then(
      (_) => setState(
        () {
          _loadedView = true;
        },
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    if (!_loadedView) animationTransitionEnded();

    Widget scanner = Container(
      color: Colors.black,
    );

    if (!_loadedView) {
      scanner = Container(
        color: Colors.black,
        width: double.infinity,
        height: double.infinity,
      );
    } else if (Platform.isAndroid) {
      scanner = Container(
        color: Colors.black,
        child: AndroidView(
          viewType: NativeScannerView.viewType,
          layoutDirection: Directionality.of(context),
          creationParams: {
            'method_channel_id': widget.methodChannelId,
            'event_channel_id': widget.eventChannelId,
          },
          creationParamsCodec: const StandardMessageCodec(),
        ),
      );
    } else if (Platform.isIOS) {
      scanner = Container(
        color: Colors.black,
        child: UiKitView(
          viewType: NativeScannerView.viewType,
          layoutDirection: Directionality.of(context),
          creationParams: {
            'method_channel_id': widget.methodChannelId,
            'event_channel_id': widget.eventChannelId,
          },
          creationParamsCodec: const StandardMessageCodec(),
        ),
      );
    }

    return scanner;
  }
}
