import 'package:hive/hive.dart';
import 'package:hive_flutter/hive_flutter.dart';
import 'package:injectable/injectable.dart';
import 'package:scanfood/infrastructure/repository/hive/model/objects/hive_product.dart';
import 'package:scanfood/infrastructure/repository/hive/model/value_objects/hive_barcode.dart';
import 'package:scanfood/infrastructure/repository/hive/model/value_objects/hive_enums.dart';

@lazySingleton
class HiveProvider {
  static const PRODUCT_BOX = 'Products';
  bool _initializing = false;

  Map<String, Box>? _database;

  Future<Map<String, Box>> get database async {
    if (_initializing) {
      await Future.delayed(const Duration(milliseconds: 50));
      return database;
    }

    _database ??= await _initialize();
    return _database!;
  }

  Future<void> dispose() async {
    await Hive.close();
    _database = null;
  }

  Future<Map<String, Box>> _initialize() async {
    _initializing = true;
    await Hive.initFlutter();

    Hive
      ..registerAdapter(HiveBarcodeAdapter())
      ..registerAdapter(HiveNutrientLevelAdapter())
      ..registerAdapter(HiveEcoScoreLevelAdapter())
      ..registerAdapter(HiveNutriScoreLevelAdapter())
      ..registerAdapter(HiveNOVAAdapter())
      ..registerAdapter(HiveAllergensAdapter())
      ..registerAdapter(HiveProductAdapter());

    final Map<String, Box> boxes = {};
    boxes[HiveProduct.BOX_NAME] = await Hive.openBox<HiveProduct>(PRODUCT_BOX);

    _initializing = false;
    return boxes;
  }
}
