import 'package:hive_flutter/hive_flutter.dart';
import 'package:injectable/injectable.dart';
import 'package:scanfood/domain/errors/no_product_found_error.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/domain/model/value_objects/barcode.dart';
import 'package:scanfood/infrastructure/providers/hive_provider.dart';
import 'package:scanfood/infrastructure/repository/hive/model/objects/hive_product.dart';

@injectable
class HiveProductRepository {
  static const BOX_NAME = HiveProvider.PRODUCT_BOX;
  final HiveProvider _hiveProvider;
  Box? _box;

  HiveProductRepository(this._hiveProvider);

  Future<Box> get box async {
    _box ??= (await _hiveProvider.database)[BOX_NAME]!;
    return _box!;
  }

  Future<Product> findProductByBarcode(Barcode barcode) async {
    final Box b = await box;
    final HiveProduct? hiveProduct = await b.get(barcode.code);
    if (hiveProduct == null) throw NoProductFoundError();

    return hiveProduct.toProduct();
  }

  Future<void> saveProduct(Product product) async {
    final Box b = await box;
    final HiveProduct hiveProduct = HiveProduct.fromProduct(product);

    await b.put(product.barcode.code, hiveProduct);
  }

  Future<List<Product>> getAll() async {
    final List<Product> products = [];

    final Box b = await box;
    for (final String key in b.keys) {
      products.add(await findProductByBarcode(Barcode(code: key)));
    }
    return products;
    /*..sort(
    (Product a, Product b) => a.lastUpdateDate.millisecondsSinceEpoch.compareTo(
    b.lastUpdateDate.millisecondsSinceEpoch,
    ),
    );*/
  }
}
