import 'package:hive/hive.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/infrastructure/providers/hive_provider.dart';
import 'package:scanfood/infrastructure/repository/hive/model/value_objects/hive_barcode.dart';
import 'package:scanfood/infrastructure/repository/hive/model/value_objects/hive_enums.dart';

part 'hive_product.g.dart';

@HiveType(typeId: 0)
class HiveProduct extends HiveObject {
  static const BOX_NAME = HiveProvider.PRODUCT_BOX;

  @HiveField(0)
  final String productName;
  @HiveField(1)
  final HiveBarcode barcode;
  @HiveField(2)
  final HiveNutrientLevel sugarsLevel;
  @HiveField(3)
  final HiveNutrientLevel fatLevel;
  @HiveField(4)
  final HiveNutrientLevel saturatedFatLevel;
  @HiveField(5)
  final HiveNutrientLevel saltLevel;
  @HiveField(6)
  final HiveEcoScoreLevel ecoScoreLevel;
  @HiveField(7)
  final HiveNutriScoreLevel nutriScoreLevel;
  @HiveField(8)
  final HiveNOVA nova;
  @HiveField(9)
  final List<HiveAllergens> allergens;
  @HiveField(10)
  final String imageUrl;
  @HiveField(11)
  final String brand;
  @HiveField(12)
  final String quantity;
  @HiveField(13)
  final double? salt;
  @HiveField(14)
  final double? fat;
  @HiveField(15)
  final double? saturatedFat;
  @HiveField(16)
  final double? sugars;

  HiveProduct({
    required this.productName,
    required this.barcode,
    required this.quantity,
    required this.sugarsLevel,
    required this.fatLevel,
    required this.saturatedFatLevel,
    required this.saltLevel,
    required this.ecoScoreLevel,
    required this.nova,
    required this.nutriScoreLevel,
    required this.allergens,
    required this.imageUrl,
    required this.brand,
    required this.salt,
    required this.fat,
    required this.saturatedFat,
    required this.sugars,
  });

  Product toProduct() => Product(
        productName: productName,
        brand: brand,
        quantity: quantity,
        barcode: barcode.toBarcode(),
        sugarsLevel: EnumFactory.hiveNutrientLevelToNutrientLevel(sugarsLevel),
        fatLevel: EnumFactory.hiveNutrientLevelToNutrientLevel(fatLevel),
        saturatedFatLevel: EnumFactory.hiveNutrientLevelToNutrientLevel(saturatedFatLevel),
        saltLevel: EnumFactory.hiveNutrientLevelToNutrientLevel(saltLevel),
        ecoScoreLevel: EnumFactory.hiveEcoScoreLevelToEcoScoreLevel(ecoScoreLevel),
        nova: EnumFactory.hiveNOVAToNOVA(nova),
        nutriScoreLevel: EnumFactory.hiveNutriScoreLevelToNutriScoreLevel(nutriScoreLevel),
        allergens: allergens.map(EnumFactory.hiveAllergensToAllergens).toList(),
        imageUrl: imageUrl,
        fat: fat,
        salt: salt,
        saturatedFat: saturatedFat,
        sugars: sugars,
      );

  factory HiveProduct.fromProduct(Product product) => HiveProduct(
        productName: product.productName,
        brand: product.brand,
        quantity: product.quantity,
        barcode: HiveBarcode.fromBarcode(product.barcode),
        sugarsLevel: EnumFactory.nutrientLevelToHiveNutrientLevel(product.sugarsLevel),
        fatLevel: EnumFactory.nutrientLevelToHiveNutrientLevel(product.fatLevel),
        saturatedFatLevel: EnumFactory.nutrientLevelToHiveNutrientLevel(product.saturatedFatLevel),
        saltLevel: EnumFactory.nutrientLevelToHiveNutrientLevel(product.saltLevel),
        ecoScoreLevel: EnumFactory.ecoScoreLevelToHiveScoreLevel(product.ecoScoreLevel),
        nova: EnumFactory.novaToHiveNOVA(product.nova),
        nutriScoreLevel: EnumFactory.nutriScoreLevelToHiveNutriScoreLevel(product.nutriScoreLevel),
        allergens: product.allergens.map(EnumFactory.allergensToHiveAllergens).toList(),
        imageUrl: product.imageUrl,
        sugars: product.sugars,
        saturatedFat: product.saturatedFat,
        salt: product.salt,
        fat: product.fat,
      );
}
