import 'dart:async';

import 'package:injectable/injectable.dart';
import 'package:scanfood/core/local_storage/core_local_storage.dart';
import 'package:scanfood/domain/repository/onboarding_status_repository.dart';

@Injectable(as: OnboardingStatusRepository)
class LocalStorageOnboardingStatusRepository implements OnboardingStatusRepository {
  static const String ONBOARDING_SHOWED = 'onboarding_showed';

  final CoreLocalStorage _coreLocalStorage;

  const LocalStorageOnboardingStatusRepository(this._coreLocalStorage);

  @override
  FutureOr<bool> hasToShowOnboarding() {
    bool hasToShowOnboarding = true;

    if (_coreLocalStorage.hasData(ONBOARDING_SHOWED)) {
      hasToShowOnboarding = !_coreLocalStorage.read<bool>(ONBOARDING_SHOWED);
    }

    return hasToShowOnboarding;
  }

  @override
  FutureOr<void> onboardShowed() => _coreLocalStorage.write(ONBOARDING_SHOWED, true);
}
