import 'package:injectable/injectable.dart';
import 'package:openfoodfacts/model/parameter/SearchTerms.dart';
import 'package:openfoodfacts/openfoodfacts.dart' as OpenFoodFactsLibrary;
import 'package:scanfood/domain/errors/no_product_found_error.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/domain/model/value_objects/barcode.dart';
import 'package:scanfood/infrastructure/factory/open_food_facts_product_to_product.dart';

@injectable
class OpenFoodFactsProductRepository {
  static const fields = [
    OpenFoodFactsLibrary.ProductField.ALLERGENS,
    OpenFoodFactsLibrary.ProductField.BARCODE,
    OpenFoodFactsLibrary.ProductField.NAME,
    OpenFoodFactsLibrary.ProductField.IMAGE_FRONT_URL,
    OpenFoodFactsLibrary.ProductField.ECOSCORE_GRADE,
    OpenFoodFactsLibrary.ProductField.NUTRISCORE,
    OpenFoodFactsLibrary.ProductField.ENVIRONMENT_IMPACT_LEVELS,
    OpenFoodFactsLibrary.ProductField.NUTRIENT_LEVELS,
    OpenFoodFactsLibrary.ProductField.QUANTITY,
    OpenFoodFactsLibrary.ProductField.BRANDS,
    OpenFoodFactsLibrary.ProductField.ATTRIBUTE_GROUPS,
    OpenFoodFactsLibrary.ProductField.NUTRIMENT_DATA_PER,
    OpenFoodFactsLibrary.ProductField.NUTRIMENTS,
  ];

  Future<Product> findProductByBarcode(Barcode barcode) async {
    final OpenFoodFactsLibrary.ProductQueryConfiguration configuration = OpenFoodFactsLibrary.ProductQueryConfiguration(
      barcode.code,
      language: OpenFoodFactsLibrary.OpenFoodFactsLanguage.SPANISH,
      fields: fields,
    );

    final OpenFoodFactsLibrary.ProductResult result =
        await OpenFoodFactsLibrary.OpenFoodAPIClient.getProduct(configuration);

    if (result.product == null) throw NoProductFoundError();

    return result.product!.toProduct();
  }

  Future<List<Product>> searchByText(String text) async {
    final List<Product> products = [];

    final OpenFoodFactsLibrary.ProductSearchQueryConfiguration configuration =
        OpenFoodFactsLibrary.ProductSearchQueryConfiguration(
      language: OpenFoodFactsLibrary.OpenFoodFactsLanguage.SPANISH,
      fields: fields,
      parametersList: [SearchTerms(terms: text.split(' '))],
    );

    final OpenFoodFactsLibrary.SearchResult result = await OpenFoodFactsLibrary.OpenFoodAPIClient.searchProducts(
      null,
      configuration,
    );

    products.addAll(result.products?.map((e) => e.toProduct()).toList() ?? []);

    return products;
  }
}
