import 'package:flutter/material.dart';
import 'package:scanfood/ui/theme/app_theme.dart';

import 'common_button.dart';

class CommonActionModal extends StatelessWidget {
  final String title;
  final String? subtitle;
  final List<CommonButton> horizontalButtons;

  CommonActionModal({
    required this.title,
    this.subtitle,
    this.horizontalButtons = const [],
  });

  @override
  Widget build(BuildContext context) {
    final List<Widget> content = [
      Text(
        title,
        textAlign: TextAlign.center,
        style: Theme.of(context).textTheme.headline4!.copyWith(
              color: AppTheme.neutral200,
            ),
      ),
    ];

    if (subtitle != null) {
      content.addAll([
        const SizedBox(height: 21),
        Text(
          subtitle!,
          textAlign: TextAlign.center,
          style: Theme.of(context).textTheme.headline4!.copyWith(
                fontWeight: FontWeight.normal,
                fontSize: 16,
                color: AppTheme.neutral200,
              ),
        ),
      ]);
    }

    if (horizontalButtons.isNotEmpty) {
      final List<Widget> rowItems = [];
      horizontalButtons.asMap().forEach((index, CommonButton button) {
        rowItems.add(Expanded(child: button));
        if (index < horizontalButtons.length - 1) rowItems.add(const SizedBox(width: 16));
      });

      content.addAll([
        const SizedBox(height: 24),
        Row(mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: rowItems),
      ]);
    }

    final Widget wrappedContent = Padding(
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 24),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        mainAxisSize: MainAxisSize.min,
        children: content,
      ),
    );

    return Dialog(
      insetPadding: const EdgeInsets.all(24),
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.all(Radius.circular(12.0)),
        side: BorderSide(
          color: AppTheme.neutral900,
        ),
      ),
      backgroundColor: AppTheme.neutral900,
      child: wrappedContent,
    );
  }
}
