import 'package:flutter/material.dart';
import 'package:scanfood/ui/theme/app_theme.dart';

class CommonAppBar extends StatelessWidget with PreferredSizeWidget {
  static const Size pSize = Size.fromHeight(50.0);

  @override
  final Size preferredSize;
  final double? elevation;
  final String title;
  final Widget? leadingWidget;
  final String? leading;
  final String? action;
  final Widget? actionWidget;
  final bool isActionActive;
  final VoidCallback? onLeading;
  final VoidCallback? onAction;
  final Color backgroundColor;

  CommonAppBar({
    this.title = '',
    this.leadingWidget,
    this.leading,
    this.action,
    this.actionWidget,
    this.isActionActive = true,
    this.onLeading,
    this.onAction,
    this.elevation,
    Color? backgroundColor,
  })  : preferredSize = pSize,
        backgroundColor = backgroundColor ?? AppTheme.complementary200,
        super();

  @override
  Widget build(BuildContext context) {
    return AppBar(
      backgroundColor: backgroundColor,
      elevation: elevation,
      leadingWidth: 90,
      leading: leading != null
          ? TextButton(
              onPressed: onLeading,
              child: Text(
                leading!,
                style: Theme.of(context).textTheme.bodyText1!.copyWith(
                      fontSize: 16,
                      color: AppTheme.neutral200,
                    ),
              ),
            )
          : GestureDetector(
              onTap: onLeading,
              child: leadingWidget ?? Container(),
            ),
      title: Text(
        title,
        style: Theme.of(context).textTheme.bodyText1!.copyWith(
              fontSize: 16,
            ),
      ),
      centerTitle: true,
      actions: [
        _CommonAppBarActionButton(
          isActionActive: isActionActive,
          onAction: onAction,
          action: action,
          actionWidget: actionWidget,
        ),
      ],
    );
  }
}

class _CommonAppBarActionButton extends StatelessWidget {
  const _CommonAppBarActionButton({
    Key? key,
    required this.isActionActive,
    required this.onAction,
    required this.action,
    required this.actionWidget,
  }) : super(key: key);

  final bool isActionActive;
  final VoidCallback? onAction;
  final String? action;
  final Widget? actionWidget;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsetsDirectional.only(end: 8.0),
      child: action != null
          ? TextButton(
              onPressed: () {
                if (isActionActive && onAction != null) onAction!();
              },
              child: Text(
                action!,
                style: Theme.of(context).textTheme.button!.copyWith(
                      color: isActionActive ? AppTheme.primary50 : AppTheme.primary800,
                    ),
              ),
            )
          : actionWidget != null
              ? GestureDetector(
                  onTap: () {
                    if (isActionActive && onAction != null) onAction!();
                  },
                  child: actionWidget ?? Container(),
                )
              : Container(),
    );
  }
}
