import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:scanfood/application/allergens/allergen_to_translation.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/resources/l10n/l10n.dart';
import 'package:scanfood/ui/theme/app_theme.dart';

enum AllergenAction {
  add,
  remove,
}

typedef CallbackAllergen = Function(AllergenAction, Allergens);

class CommonBottomModalFilter extends StatelessWidget {
  final AllergenToTranslation allergenToTranslation = GetIt.I.get<AllergenToTranslation>();
  final Set<Allergens> allergensDisabled;
  final CallbackAllergen callbackAllergen;

  CommonBottomModalFilter({
    Key? key,
    required this.allergensDisabled,
    required this.callbackAllergen,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(20),
          topRight: Radius.circular(20),
        ),
        boxShadow: [
          BoxShadow(
            color: Colors.white,
            spreadRadius: 3,
          ),
        ],
      ),
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 12),
          child: Column(
            children: [
              const SizedBox(
                height: 8,
              ),
              FractionallySizedBox(
                widthFactor: 0.45,
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(15.0),
                  child: const Divider(
                    height: 6,
                    color: AppTheme.neutral600,
                    thickness: 6,
                  ),
                ),
              ),
              const SizedBox(
                height: 12,
              ),
              Container(
                padding: const EdgeInsets.symmetric(vertical: 6),
                width: MediaQuery.of(context).size.width * 0.95,
                color: AppTheme.neutral400,
                child: Align(
                  alignment: Alignment.center,
                  child: Text(
                    S.of(context).remove_allergens_title,
                    style: Theme.of(context).textTheme.headline4!.copyWith(fontWeight: FontWeight.normal),
                  ),
                ),
              ),
              const SizedBox(
                height: 12,
              ),
              ...allergensWidgets(),
            ],
          ),
        ),
      ),
    );
  }

  List<_AllergenRow> allergensWidgets() {
    final List<_AllergenRow> allergenWidgets = [];

    allergenToTranslation.allergenMap().forEach(
          (allergen, text) => allergenWidgets.add(
            _AllergenRow(
              rowSelected: allergensDisabled.contains(allergen),
              allergenText: text,
              onTap: () {
                if (allergensDisabled.contains(allergen)) {
                  callbackAllergen(AllergenAction.remove, allergen);
                  allergensDisabled.remove(allergen);
                } else {
                  callbackAllergen(AllergenAction.add, allergen);
                  allergensDisabled.add(allergen);
                }
              },
            ),
          ),
        );

    return allergenWidgets;
  }
}

class _AllergenRow extends StatefulWidget {
  final String allergenText;
  final VoidCallback onTap;
  final bool rowSelected;

  const _AllergenRow({
    Key? key,
    required this.allergenText,
    required this.onTap,
    required this.rowSelected,
  }) : super(key: key);

  @override
  State<_AllergenRow> createState() => _AllergenRowState(rowSelected);
}

class _AllergenRowState extends State<_AllergenRow> {
  bool rowSelected;

  _AllergenRowState(this.rowSelected);

  void toggleRow() {
    widget.onTap.call();
    setState(() {
      rowSelected = !rowSelected;
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: toggleRow,
      child: Row(
        children: [
          Expanded(child: Text(widget.allergenText)),
          Checkbox(value: rowSelected, onChanged: (_) => toggleRow()),
        ],
      ),
    );
  }
}
