import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/ui/helpers/product_qualifiers_to_svg.dart';
import 'package:scanfood/ui/item_screen/item_page.dart';
import 'package:scanfood/ui/theme/app_theme.dart';

class CommonProductListElement extends StatelessWidget with ProductQualifiersToSvg {
  final Product product;

  const CommonProductListElement({
    Key? key,
    required this.product,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        Navigator.of(context).pushNamed(ItemPage.ROUTE, arguments: ItemPageParams(product: product));
      },
      child: Padding(
        padding: const EdgeInsets.all(10),
        child: Container(
          padding: const EdgeInsets.symmetric(horizontal: 8, vertical: 12),
          decoration: const BoxDecoration(
            border: Border(
              bottom: BorderSide(width: 1, color: AppTheme.neutral600),
            ),
          ),
          height: 120,
          child: Row(
            children: [
              SizedBox(
                child: CachedNetworkImage(
                  imageUrl: product.imageUrl,
                  width: 60,
                ),
              ),
              const SizedBox(
                width: 8,
              ),
              Expanded(
                child: Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 4),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        '${product.productName} - ${product.quantity}',
                        style: Theme.of(context).textTheme.bodyText1!.copyWith(
                              fontWeight: FontWeight.bold,
                            ),
                        maxLines: 1,
                      ),
                      Text(
                        product.brand,
                        style: Theme.of(context).textTheme.bodyText1,
                        maxLines: 1,
                      ),
                      Row(
                        mainAxisSize: MainAxisSize.max,
                        mainAxisAlignment: MainAxisAlignment.end,
                        crossAxisAlignment: CrossAxisAlignment.end,
                        children: [
                          SvgPicture.asset(
                            nutriscoreToSvg(product.nutriScoreLevel),
                            height: 45,
                          ),
                          const SizedBox(
                            width: 8,
                          ),
                          SvgPicture.asset(
                            novaToSvg(product.nova),
                            height: 45,
                          ),
                          const SizedBox(
                            width: 8,
                          ),
                          SvgPicture.asset(
                            ecoScoreToSvg(product.ecoScoreLevel),
                            height: 45,
                          ),
                        ],
                      )
                    ],
                  ),
                ),
              ),
              const Icon(Icons.arrow_forward_ios),
            ],
          ),
        ),
      ),
    );
  }
}
