import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:get_it/get_it.dart';
import 'package:scanfood/application/history_page_bloc/history_page_cubit.dart';
import 'package:scanfood/application/list_cubit/list_cubit.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/resources/l10n/l10n.dart';
import 'package:scanfood/ui/common/common_app_bar.dart';
import 'package:scanfood/ui/common/common_bottom_modal_filter.dart';
import 'package:scanfood/ui/common/common_product_list_element.dart';

class HistoryPage extends StatelessWidget {
  static const ROUTE = '/history-screen';

  const HistoryPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final HistoryPageCubit _historyPageCubit = GetIt.I.get<HistoryPageCubit>()..loadHistory();

    return Scaffold(
      appBar: CommonAppBar(
        title: S.of(context).history,
        actionWidget: Row(
          children: [
            SvgPicture.asset(
              'assets/icons/filter-variant.svg',
              width: 24,
              height: 24,
            ),
            Text(
              S.of(context).filter,
              style: Theme.of(context).textTheme.bodyText1!.copyWith(
                    color: Colors.black,
                  ),
            ),
          ],
        ),
        isActionActive: true,
        onAction: () {
          showModalBottomSheet(
            context: context,
            builder: (_) => BlocBuilder(
              bloc: _historyPageCubit,
              builder: (context, ListState state) {
                return CommonBottomModalFilter(
                  callbackAllergen: (AllergenAction allergenAction, Allergens allergens) {
                    switch (allergenAction) {
                      case AllergenAction.add:
                        _historyPageCubit.addFilterToAllergens(allergens);
                        break;
                      case AllergenAction.remove:
                        _historyPageCubit.removeFiltertoAllergens(allergens);
                        break;
                    }
                  },
                  allergensDisabled: state.disabledAllergens,
                );
              },
            ),
          );
        },
      ),
      body: BlocBuilder(
        bloc: _historyPageCubit,
        builder: (context, ListState state) {
          return ListView.builder(
            itemBuilder: (context, itemNumber) {
              return CommonProductListElement(product: state.products.elementAt(itemNumber));
            },
            itemCount: state.products.length,
          );
        },
      ),
    );
  }
}
