part of 'item_page.dart';

class _ItemPageContents extends StatelessWidget with ProductQualifiersToSvg, AllergensToString {
  final Product product;

  const _ItemPageContents({
    Key? key,
    required this.product,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: CommonAppBar(
        leadingWidget: const Icon(
          Icons.arrow_back,
          color: Colors.black,
        ),
        onLeading: () {
          Navigator.of(context).pop();
        },
        title: product.productName,
      ),
      body: Stack(
        alignment: Alignment.center,
        children: [
          Positioned.fill(
            child: Padding(
              padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      SizedBox(
                        child: CachedNetworkImage(
                          imageUrl: product.imageUrl,
                          height: 125,
                          width: 100,
                          fit: BoxFit.scaleDown,
                        ),
                      ),
                      const SizedBox(
                        width: 16,
                      ),
                      Expanded(
                        child: Row(
                          mainAxisSize: MainAxisSize.max,
                          mainAxisAlignment: MainAxisAlignment.end,
                          crossAxisAlignment: CrossAxisAlignment.end,
                          children: [
                            SvgPicture.asset(
                              nutriscoreToSvg(product.nutriScoreLevel),
                              height: 50,
                            ),
                            const SizedBox(
                              width: 8,
                            ),
                            SvgPicture.asset(
                              novaToSvg(product.nova),
                              height: 50,
                            ),
                            const SizedBox(
                              width: 8,
                            ),
                            SvgPicture.asset(
                              ecoScoreToSvg(product.ecoScoreLevel),
                              height: 50,
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 16,
                  ),
                  const Divider(
                    height: 1,
                    color: AppTheme.neutral500,
                    thickness: 1,
                  ),
                  const SizedBox(
                    height: 16,
                  ),
                  _NutritionalLevels(product: product),
                  const SizedBox(
                    height: 16,
                  ),
                  const Divider(
                    height: 1,
                    color: AppTheme.neutral500,
                    thickness: 1,
                  ),
                  const SizedBox(
                    height: 16,
                  ),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        S.of(context).allergens,
                        style: Theme.of(context).textTheme.headline4,
                        textAlign: TextAlign.start,
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(
                          horizontal: 12,
                          vertical: 12,
                        ),
                        child: Text(
                          product.allergens.isEmpty
                              ? S.of(context).no_allergens
                              : '${allergensToString(product.allergens).join(', ')}.',
                          style: Theme.of(context).textTheme.bodyText2,
                          textAlign: TextAlign.start,
                        ),
                      )
                    ],
                  ),
                ],
              ),
            ),
          ),
          Positioned(
            bottom: MediaQuery.of(context).padding.bottom,
            child: CommonAdmobBannerAd(),
          ),
        ],
      ),
    );
  }
}

class _NutritionalLevels extends StatelessWidget {
  const _NutritionalLevels({
    Key? key,
    required this.product,
  }) : super(key: key);

  final Product product;

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          S.of(context).nutritional_levels,
          style: Theme.of(context).textTheme.headline4,
          textAlign: TextAlign.start,
        ),
        const SizedBox(
          height: 16,
        ),
        _hasNutrientsReported()
            ? Column(
                children: [
                  _NutritionLevel(
                    nutritionLevel: product.fatLevel,
                    text: '${product.fat} g ${S.of(context).fats}',
                  ),
                  const SizedBox(
                    height: 8,
                  ),
                  _NutritionLevel(
                    nutritionLevel: product.saturatedFatLevel,
                    text: '${product.saturatedFat} g ${S.of(context).saturated_fat}',
                  ),
                  const SizedBox(
                    height: 8,
                  ),
                  _NutritionLevel(
                    nutritionLevel: product.sugarsLevel,
                    text: '${product.sugars} g ${S.of(context).sugars}',
                  ),
                  const SizedBox(
                    height: 8,
                  ),
                  _NutritionLevel(
                    nutritionLevel: product.saltLevel,
                    text: '${product.salt} g ${S.of(context).salt}',
                  ),
                ],
              )
            : Padding(
                padding: const EdgeInsets.symmetric(
                  horizontal: 12,
                  vertical: 12,
                ),
                child: Text(
                  S.of(context).no_nutritional_levels,
                  style: Theme.of(context).textTheme.bodyText2,
                  textAlign: TextAlign.start,
                ),
              ),
      ],
    );
  }

  bool _hasNutrientsReported() {
    return product.fatLevel != NutrientLevel.unknown &&
        product.saturatedFatLevel != NutrientLevel.unknown &&
        product.sugarsLevel != NutrientLevel.unknown &&
        product.saltLevel != NutrientLevel.unknown;
  }
}

class _NutritionLevel extends StatelessWidget with NutritionLevelToColor {
  final NutrientLevel nutritionLevel;
  final String text;

  const _NutritionLevel({
    Key? key,
    required this.nutritionLevel,
    required this.text,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Container(
          width: 45.0,
          height: 45.0,
          decoration: BoxDecoration(
            color: nutritionLevelToColor(nutritionLevel),
            shape: BoxShape.circle,
          ),
        ),
        const SizedBox(
          width: 16,
        ),
        Text(text),
      ],
    );
  }
}
