import 'package:flutter/material.dart';
import 'package:scanfood/resources/l10n/l10n.dart';
import 'package:scanfood/ui/camera_page/camera_page.dart';
import 'package:scanfood/ui/history_page/history_page.dart';
import 'package:scanfood/ui/search_page/search_page.dart';
import 'package:scanfood/ui/settings_page/settings_page.dart';

class MainScreen extends StatefulWidget {
  static const ROUTE = '/main-screen';

  const MainScreen({Key? key}) : super(key: key);

  @override
  State<MainScreen> createState() => _MainScreenState();
}

class _MainScreenState extends State<MainScreen> {
  final _pageController = PageController(initialPage: 0);
  int _selectedPage = 0;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: PageView(
        physics: const NeverScrollableScrollPhysics(),
        controller: _pageController,
        onPageChanged: (value) => setState(() {
          _selectedPage = value;
        }),
        children: [
          CameraPage(pageIsBeingShown: _selectedPage == 0),
          SearchPage(),
          const HistoryPage(),
          const SettingsPage(),
        ],
      ),
      bottomNavigationBar: BottomNavigationBar(
        currentIndex: _selectedPage,
        onTap: (value) => _pageController.animateToPage(
          value,
          duration: const Duration(microseconds: 300),
          curve: Curves.easeIn,
        ),
        type: BottomNavigationBarType.fixed,
        items: [
          BottomNavigationBarItem(
            icon: const Icon(Icons.camera_alt),
            label: S.of(context).camera,
          ),
          BottomNavigationBarItem(
            icon: const Icon(Icons.search),
            label: S.of(context).search,
          ),
          BottomNavigationBarItem(
            icon: const Icon(Icons.history),
            label: S.of(context).history,
          ),
          BottomNavigationBarItem(
            icon: const Icon(Icons.settings),
            label: S.of(context).settings,
          ),
        ],
      ),
    );
  }
}
