import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:get_it/get_it.dart';
import 'package:introduction_screen/introduction_screen.dart';
import 'package:lottie/lottie.dart';
import 'package:scanfood/application/service/onboarding_notifier_service.dart';
import 'package:scanfood/resources/l10n/l10n.dart';
import 'package:scanfood/ui/main_screen/main_screen.dart';
import 'package:scanfood/ui/theme/app_theme.dart';

class OnboardingScreen extends StatelessWidget {
  static const ROUTE = '/onboarding';

  const OnboardingScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(toolbarHeight: 0),
      body: SafeArea(
        top: false,
        child: IntroductionScreen(
          pages: [
            PageViewModel(
              image: Lottie.asset('assets/lottie/scanning.json'),
              title: S.of(context).onboarding_title_1,
              body: S.of(context).onboarding_description_1,
              decoration: const PageDecoration(
                imageFlex: 6,
                bodyFlex: 5,
              ),
            ),
            PageViewModel(
              image: Lottie.asset('assets/lottie/healthy_food.json'),
              title: S.of(context).onboarding_title_2,
              body: S.of(context).onboarding_description_3,
              decoration: const PageDecoration(
                imageFlex: 6,
                bodyFlex: 5,
              ),
            ),
            PageViewModel(
              image: Lottie.asset('assets/lottie/food_bowl.json'),
              title: S.of(context).onboarding_title_3,
              body: S.of(context).onboarding_description_3,
              decoration: const PageDecoration(
                imageFlex: 6,
                bodyFlex: 5,
              ),
            ),
          ],
          showDoneButton: true,
          showNextButton: true,
          showSkipButton: true,
          onDone: () {
            _continueToMainScreen(context);
          },
          onSkip: () {
            _continueToMainScreen(context);
          },
          done: SvgPicture.asset(
            'assets/icons/arrow-onboarding.svg',
            color: AppTheme.primary800,
          ),
          skip: Text(
            S.of(context).onboarding_skip,
            style: Theme.of(context).textTheme.headline4!.copyWith(color: AppTheme.primary800),
          ),
          next: SvgPicture.asset(
            'assets/icons/arrow-onboarding.svg',
            color: AppTheme.primary800,
          ),
          dotsDecorator: const DotsDecorator(
            activeColor: AppTheme.primary800,
            color: AppTheme.primary200,
          ),
        ),
      ),
    );
  }

  void _continueToMainScreen(BuildContext context) {
    GetIt.I.get<OnboardingNotifierService>().execute();

    Navigator.of(context).pushReplacementNamed(MainScreen.ROUTE);
  }
}
