import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get_it/get_it.dart';
import 'package:scanfood/application/list_cubit/list_cubit.dart';
import 'package:scanfood/application/scan_result_bloc/scan_result_cubit.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/resources/l10n/l10n.dart';
import 'package:scanfood/ui/common/common_admob_banner_ad.dart';
import 'package:scanfood/ui/common/common_app_bar.dart';
import 'package:scanfood/ui/common/common_bottom_modal_filter.dart';
import 'package:scanfood/ui/common/common_product_list_element.dart';

class ResultPage extends StatelessWidget {
  static const ROUTE = '/results';

  const ResultPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final ScanResultCubit _scanResultCubit = GetIt.I.get<ScanResultCubit>();

    return Scaffold(
      appBar: CommonAppBar(
        title: S.of(context).scan_results,
        actionWidget: Row(
          children: [
            SvgPicture.asset(
              'assets/icons/filter-variant.svg',
              width: 24,
              height: 24,
            ),
            Text(
              S.of(context).filter,
              style: Theme.of(context).textTheme.bodyText1!.copyWith(
                    color: Colors.black,
                  ),
            ),
          ],
        ),
        isActionActive: true,
        onAction: () {
          showModalBottomSheet(
            context: context,
            builder: (_) => BlocBuilder(
              bloc: _scanResultCubit,
              builder: (context, ListState state) {
                return CommonBottomModalFilter(
                  callbackAllergen: (AllergenAction allergenAction, Allergens allergens) {
                    switch (allergenAction) {
                      case AllergenAction.add:
                        _scanResultCubit.addFilterToAllergens(allergens);
                        break;
                      case AllergenAction.remove:
                        _scanResultCubit.removeFiltertoAllergens(allergens);
                        break;
                    }
                  },
                  allergensDisabled: state.disabledAllergens,
                );
              },
            ),
          );
        },
        leadingWidget: const Icon(
          Icons.arrow_back,
          color: Colors.black,
        ),
        onLeading: () {
          Navigator.of(context).pop();
        },
      ),
      body: Stack(
        alignment: Alignment.center,
        children: [
          Positioned.fill(
            child: BlocBuilder(
              bloc: _scanResultCubit,
              builder: (context, ListState state) {
                return ListView.builder(
                  itemBuilder: (context, itemNumber) {
                    if (itemNumber == state.products.length) {
                      return const SizedBox(
                        height: 50,
                      );
                    }
                    return CommonProductListElement(product: state.products.elementAt(itemNumber));
                  },
                  itemCount: state.products.length + 1,
                );
              },
            ),
          ),
          Positioned(
            bottom: MediaQuery.of(context).padding.bottom,
            child: CommonAdmobBannerAd(),
          ),
        ],
      ),
    );
  }
}
