import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:get_it/get_it.dart';
import 'package:scanfood/application/list_cubit/list_cubit.dart';
import 'package:scanfood/application/search_bloc/search_cubit.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/resources/l10n/l10n.dart';
import 'package:scanfood/ui/common/common_bottom_modal_filter.dart';
import 'package:scanfood/ui/common/common_product_list_element.dart';
import 'package:scanfood/ui/theme/app_theme.dart';

class SearchPage extends StatelessWidget {
  final SearchCubit _searchCubit = GetIt.I.get<SearchCubit>();

  SearchPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        toolbarHeight: 95,
        flexibleSpace: SafeArea(
          child: Container(
            padding: const EdgeInsets.only(top: 8, left: 12, right: 12),
            color: AppTheme.complementary200,
            child: Column(children: [
              Text(
                S.of(context).search,
                style: Theme.of(context).textTheme.bodyText1!.copyWith(
                      fontSize: 16,
                    ),
              ),
              const SizedBox(
                height: 8,
              ),
              Row(
                children: [
                  Expanded(
                    child: _SearchField(
                      searchCallback: (text) {
                        _searchCubit.search(text);
                      },
                    ),
                  ),
                  const SizedBox(
                    width: 8,
                  ),
                  GestureDetector(
                    onTap: () {
                      showModalBottomSheet(
                        context: context,
                        builder: (_) => BlocBuilder(
                          bloc: _searchCubit,
                          builder: (context, ListState state) {
                            return CommonBottomModalFilter(
                              callbackAllergen: (AllergenAction allergenAction, Allergens allergens) {
                                switch (allergenAction) {
                                  case AllergenAction.add:
                                    _searchCubit.addFilterToAllergens(allergens);
                                    break;
                                  case AllergenAction.remove:
                                    _searchCubit.removeFiltertoAllergens(allergens);
                                    break;
                                }
                              },
                              allergensDisabled: state.disabledAllergens,
                            );
                          },
                        ),
                      );
                    },
                    child: Row(
                      children: [
                        SvgPicture.asset(
                          'assets/icons/filter-variant.svg',
                          width: 24,
                          height: 24,
                        ),
                        Text(
                          S.of(context).filter,
                          style: Theme.of(context).textTheme.bodyText1!.copyWith(
                                color: Colors.black,
                              ),
                        ),
                      ],
                    ),
                  ),
                ],
              )
            ]),
          ),
        ),
      ),
      body: BlocBuilder(
        bloc: _searchCubit,
        builder: (context, ListState state) {
          Widget widget = const SizedBox.shrink();

          if (state.loading) {
            widget = const Center(
              child: CircularProgressIndicator(),
            );
          } else if (!state.userHasSearched) {
            widget = Padding(
              padding: const EdgeInsets.symmetric(
                horizontal: 24,
              ),
              child: Center(
                child: Text(
                  S.of(context).use_top_search_bar,
                  textAlign: TextAlign.center,
                  style: Theme.of(context).textTheme.bodyText1,
                ),
              ),
            );
          } else if (state.products.isEmpty) {
            widget = Padding(
              padding: const EdgeInsets.symmetric(
                horizontal: 24,
              ),
              child: Center(
                child: Text(
                  S.of(context).no_results,
                  textAlign: TextAlign.center,
                  style: Theme.of(context).textTheme.bodyText1,
                ),
              ),
            );
          } else {
            widget = ListView.builder(
              itemBuilder: (context, itemNumber) {
                return CommonProductListElement(product: state.products.elementAt(itemNumber));
              },
              itemCount: state.products.length,
            );
          }

          return widget;
        },
      ),
    );
  }
}

class _SearchField extends StatefulWidget {
  final Function(String) searchCallback;

  const _SearchField({
    Key? key,
    required this.searchCallback,
  }) : super(key: key);

  @override
  State<_SearchField> createState() => _SearchFieldState();
}

class _SearchFieldState extends State<_SearchField> {
  final TextEditingController _textEditingController = TextEditingController();

  @override
  void dispose() {
    _textEditingController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return CupertinoTextField(
      controller: _textEditingController,
      prefix: const Padding(
        padding: EdgeInsets.all(10),
        child: Icon(Icons.search),
      ),
      suffix: GestureDetector(
        child: const Padding(
          padding: EdgeInsets.all(10),
          child: Icon(Icons.clear),
        ),
        onTap: _textEditingController.clear,
      ),
      suffixMode: OverlayVisibilityMode.editing,
      onSubmitted: widget.searchCallback,
    );
  }
}
