import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:in_app_review/in_app_review.dart';
import 'package:scanfood/resources/l10n/l10n.dart';
import 'package:scanfood/ui/common/common_app_bar.dart';
import 'package:scanfood/ui/theme/app_theme.dart';
import 'package:url_launcher/url_launcher.dart';

class SettingsPage extends StatelessWidget {
  const SettingsPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: CommonAppBar(
        title: S.of(context).settings,
      ),
      body: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 24),
        child: Column(
          children: [
            FutureBuilder(
              future: InAppReview.instance.isAvailable(),
              builder: (_, __) {
                return _SettingsButton(
                  buttonCallback: InAppReview.instance.requestReview,
                  iconPath: 'assets/icons/star.svg',
                  text: S.of(context).rate_app,
                );
              },
            ),
            const SizedBox(
              height: 12,
            ),
            /* OUT OF MVP
            _SettingsButton(
              buttonCallback: () {},
              iconPath: 'assets/icons/account-cog.svg',
              text: S.of(context).allergens_preference,
            ),
            const SizedBox(
              height: 12,
            ),*/
            _SettingsButton(
              buttonCallback: () {
                launch('https://scanfood.app/terms_and_conditions');
              },
              iconPath: 'assets/icons/application.svg',
              text: S.of(context).terms_and_conditions,
            ),
            const SizedBox(
              height: 12,
            ),
            _SettingsButton(
              buttonCallback: () {
                launch('mailto:info@scanfood.app?subject=Contact+from+scanfood');
              },
              iconPath: 'assets/icons/email.svg',
              text: S.of(context).contact_us,
            ),
          ],
        ),
      ),
    );
  }
}

class _SettingsButton extends StatelessWidget {
  final String iconPath;
  final String text;
  final VoidCallback buttonCallback;

  const _SettingsButton({
    Key? key,
    required this.iconPath,
    required this.text,
    required this.buttonCallback,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: buttonCallback,
      child: Container(
        padding: const EdgeInsets.all(12),
        decoration: BoxDecoration(
          border: Border.all(color: AppTheme.neutral600),
        ),
        child: Row(
          children: [
            SvgPicture.asset(iconPath),
            const SizedBox(
              width: 8,
            ),
            Expanded(
              child: Text(text),
            ),
            const Icon(
              Icons.arrow_forward_ios,
              color: AppTheme.neutral900,
            ),
          ],
        ),
      ),
    );
  }
}
