import 'package:flutter/material.dart';

class AppTheme {
  AppTheme._();

  static final ThemeData lightTheme = ThemeData(
    primaryColor: primary400,
    splashColor: Colors.transparent,
    highlightColor: Colors.transparent,
    hoverColor: Colors.transparent,
    hintColor: complementary600,
    errorColor: error600,
    shadowColor: shadow,
    scaffoldBackgroundColor: neutral200,
    brightness: Brightness.light,
    appBarTheme: const AppBarTheme(
      color: complementary200,
    ),
    bottomNavigationBarTheme: const BottomNavigationBarThemeData(
      backgroundColor: primary800,
      unselectedItemColor: Colors.white,
    ),
    bottomSheetTheme: BottomSheetThemeData(
      backgroundColor: neutral500,
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(8),
          topRight: Radius.circular(8),
        ),
      ),
      modalBackgroundColor: neutral900.withOpacity(0.65),
      elevation: 0,
    ),
    dialogTheme: DialogTheme(
      backgroundColor: neutral500,
      titleTextStyle: textStyle.copyWith(
        fontSize: 18,
        fontWeight: FontWeight.bold,
      ),
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.all(
          Radius.circular(8),
        ),
      ),
      contentTextStyle: textStyle.copyWith(
        fontSize: 14,
      ),
    ),
    fontFamily: 'Poppins',
    textTheme: TextTheme(
      headline1: textStyle.copyWith(
        fontSize: 34,
        fontWeight: FontWeight.bold,
      ),
      headline2: textStyle.copyWith(
        fontSize: 24,
        fontWeight: FontWeight.bold,
      ),
      headline3: textStyle.copyWith(
        fontSize: 20,
        fontWeight: FontWeight.bold,
      ),
      headline4: textStyle.copyWith(
        fontSize: 18,
        fontWeight: FontWeight.bold,
      ),
      bodyText1: textStyle.copyWith(
        fontSize: 16,
      ),
      bodyText2: textStyle.copyWith(
        fontSize: 14,
      ),
      button: textStyle.copyWith(
        fontSize: 16,
        fontWeight: FontWeight.bold,
      ),
      caption: textStyle.copyWith(
        fontSize: 12,
      ),
    ),
    textButtonTheme: TextButtonThemeData(
      style: TextButton.styleFrom(
        primary: Colors.white,
        animationDuration: Duration.zero,
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(6),
        ),
      ),
    ),
    elevatedButtonTheme: ElevatedButtonThemeData(
      style: ElevatedButton.styleFrom(
        primary: primary400,
        onPrimary: Colors.white,
        elevation: 0,
        minimumSize: const Size.fromHeight(44),
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(6),
        ),
      ),
    ),
    outlinedButtonTheme: OutlinedButtonThemeData(
      style: OutlinedButton.styleFrom(
        primary: neutral200,
        backgroundColor: neutral600,
        elevation: 0,
        minimumSize: const Size.fromHeight(44),
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(6),
        ),
        side: const BorderSide(
          color: neutral200,
        ),
      ),
    ),
    sliderTheme: SliderThemeData(
      activeTrackColor: primary50,
      inactiveTrackColor: primary600,
      thumbColor: primary800,
      //thumbShape: ,
      trackHeight: 1,
      overlayColor: primary600.withOpacity(0.35),
    ),
    switchTheme: SwitchThemeData(
      thumbColor: MaterialStateProperty.resolveWith<Color>((states) {
        return Colors.white;
      }),
      trackColor: MaterialStateProperty.resolveWith<Color>((states) {
        if (states.contains(MaterialState.selected)) {
          return Colors.white;
        } else if (states.contains(MaterialState.disabled)) {
          return neutral700;
        } else {
          return Colors.transparent;
        }
      }),
      overlayColor: MaterialStateProperty.resolveWith((states) => primary200),
    ),
    colorScheme: ColorScheme.fromSwatch().copyWith(
      secondary: Colors.white,
      brightness: Brightness.light,
    ),
  );

  static const textStyle = TextStyle(
    color: Colors.black,
    letterSpacing: -0.5,
  );

  static const Color primary800 = Color(0xff060F4B);
  static const Color primary600 = Color(0xff253077);
  static const Color primary400 = Color(0xff676FA2);
  static const Color primary200 = Color(0xffBCBFD7);
  static const Color primary50 = Color(0xffE4E6EF);

  static const Color secondary800 = Color(0xff971D50);
  static const Color secondary600 = Color(0xffE82965);
  static const Color secondary400 = Color(0xffDE668C);
  static const Color secondary200 = Color(0xffEFA4BC);
  static const Color secondary50 = Color(0xffF7D5DF);

  static const Color complementary800 = Color(0xff009D8F);
  static const Color complementary600 = Color(0xff00BCB2);
  static const Color complementary400 = Color(0xffAAE2DE);
  static const Color complementary200 = Color(0xffDDF3F3);

  static const Color neutral900 = Color(0xff1E2021);
  static const Color neutral700 = Color(0xff3D4042);
  static const Color neutral600 = Color(0xff6D7275);
  static const Color neutral500 = Color(0xffB6BABD);
  static const Color neutral400 = Color(0xffE7EBEE);
  static const Color neutral200 = Color(0xffF5F8FA);

  static const Color error800 = Color(0xffD63737);
  static const Color error600 = Color(0xffF09D9E);
  static const Color error400 = Color(0xffFFECEF);

  static const Color shadow = Color(0xff1e2021);

  static const Color disabled200 = Color(0xff757783);

  static const Color lowLevel = Color(0xff11FC09);
  static const Color mediumLevel = Color(0xffFCE409);
  static const Color highLevel = Color(0xffFC1A09);
  static const Color undefinedLevel = neutral500;

  static const int smallDeviceWidth = 321; // iPhone SE Gen1
  static const int smallDeviceWidthGen2 = 375; // iPhone SE Gen2
  static const int smallDeviceHeight = 593; // iPhone SE Gen1
  static const int smallDeviceHeightGen2 = 667; // iPhone SE Gen2
}
