import 'package:bloc_test/bloc_test.dart';
import 'package:faker/faker.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:scanfood/application/history_page_bloc/history_page_cubit.dart';
import 'package:scanfood/application/list_cubit/list_cubit.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/domain/repository/product_repository.dart';

import '../../domain/model/object/product_mock.dart';
import 'history_cubit_test.mocks.dart';

@GenerateMocks([
  ProductRepository,
])
void main() {
  group('History cubit test', () {
    final MockProductRepository mockProductRepository = MockProductRepository();

    final Faker faker = Faker();
    final int items = faker.randomGenerator.integer(30, min: 1);
    final List<Product> p = [];

    for (var i = 0; i < items; i++) {
      p.add(generateMockProduct());
    }

    when(mockProductRepository.getAll()).thenAnswer((realInvocation) => Future.value(p));

    blocTest(
      'Test history cubit loads products',
      build: () => HistoryPageCubit(mockProductRepository),
      act: (HistoryPageCubit cubit) => cubit.loadHistory(),
      expect: () => [
        ListState(products: p.toSet(), disabledAllergens: {}, userHasSearched: true, loading: false),
      ],
      verify: (_) {
        verify(mockProductRepository.getAll()).called(1);
      },
    );
  });
}
