import 'package:bloc_test/bloc_test.dart';
import 'package:collection/collection.dart';
import 'package:faker/faker.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:scanfood/application/list_cubit/list_cubit.dart';
import 'package:scanfood/domain/model/objects/product.dart';

import '../../domain/model/object/product_mock.dart';

class FakeListCubit extends ListCubit {
  FakeListCubit(bool loading, Set<Product> products, bool userHasSearched, Set<Allergens> disabledAllergens)
      : super(loading, products, userHasSearched, disabledAllergens);
}

void main() {
  group('List cubit test - addFilterToAllergens, removeFilter', () {
    final Faker faker = Faker();
    final Allergens allergen1 = faker.randomGenerator.element(Allergens.values);
    Allergens allergen2;

    do {
      allergen2 = faker.randomGenerator.element(Allergens.values);
    } while (allergen1 == allergen2);

    final int items = 3; //faker.randomGenerator.integer(10, min: 2);
    final List<Product> p = []
      ..add(generateMockProduct(allergens: [allergen2]))
      ..add(generateMockProduct(allergens: [allergen1]));

    for (var i = 2; i < items; i++) {
      p.add(generateMockProduct());
    }

    final bool loading = faker.randomGenerator.boolean();
    final bool userHasSearched = faker.randomGenerator.boolean();

    blocTest(
      'Add and remove filters',
      build: () {
        return FakeListCubit(loading, p.toSet(), userHasSearched, {});
      },
      act: (FakeListCubit fakeListCubit) => fakeListCubit
        ..addFilterToAllergens(allergen1)
        ..addFilterToAllergens(allergen2)
        ..removeFiltertoAllergens(allergen2)
        ..removeFiltertoAllergens(allergen1),
      expect: () => pairwiseCompare([
        ListState(
          products: p.where((element) => element.allergens.toSet().intersection({allergen1}).isEmpty).toSet(),
          disabledAllergens: {allergen1},
          userHasSearched: userHasSearched,
          loading: loading,
        ),
        ListState(
          products:
              p.where((element) => element.allergens.toSet().intersection({allergen1, allergen2}).isEmpty).toSet(),
          disabledAllergens: {allergen1, allergen2},
          userHasSearched: userHasSearched,
          loading: loading,
        ),
        ListState(
          products: p.where((element) => element.allergens.toSet().intersection({allergen1}).isEmpty).toSet(),
          disabledAllergens: {allergen1},
          userHasSearched: userHasSearched,
          loading: loading,
        ),
        ListState(
          products: p.where((element) => element.allergens.toSet().intersection({}).isEmpty).toSet(),
          disabledAllergens: {},
          userHasSearched: userHasSearched,
          loading: loading,
        ),
      ], (ListState expected, ListState result) {
        Function unOrdDeepEq = const DeepCollectionEquality.unordered().equals;

        return unOrdDeepEq(expected.products.toList(), result.products.toList());
      }, 'Not matching elements'),
    );
  });
}
