import 'package:bloc_test/bloc_test.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:scanfood/application/list_cubit/list_cubit.dart';
import 'package:scanfood/application/scan_result_bloc/scan_result_cubit.dart';
import 'package:scanfood/domain/model/objects/product.dart';
import 'package:scanfood/domain/model/value_objects/barcode.dart';
import 'package:scanfood/domain/repository/product_repository.dart';

import '../../domain/model/object/product_mock.dart';
import '../../domain/model/value_objects/barcode_mock.dart';
import 'scan_result_cubit_test.mocks.dart';

@GenerateMocks([
  ProductRepository,
])
void main() {
  group('Scan result cubit', () {
    final MockProductRepository mockProductRepository = MockProductRepository();

    final Barcode barcode = generateBarcodeMock();
    final Product product = generateMockProduct(barcode: barcode);

    when(mockProductRepository.findProductByBarcode(barcode)).thenAnswer((realInvocation) => Future.value(product));

    blocTest(
      '-> add product',
      build: () => ScanResultCubit(mockProductRepository),
      act: (ScanResultCubit scanResultCubit) {
        scanResultCubit.addBarcode(barcode);
      },
      expect: () => [
        ListState(
          loading: false,
          userHasSearched: true,
          products: {product},
          disabledAllergens: {},
        ),
      ],
      verify: (ScanResultCubit scanResultCubit) {
        verify(mockProductRepository.findProductByBarcode(barcode)).called(1);
      },
    );
  });
}
