import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:scanfood/application/service/application_startup_service.dart';
import 'package:scanfood/domain/repository/onboarding_status_repository.dart';
import 'package:scanfood/domain/service/check_platform_device.dart';
import 'package:scanfood/ui/main_screen/main_screen.dart';
import 'package:scanfood/ui/onboarding_screen/onboarding_screen.dart';

import 'application_startup_service_test.mocks.dart';

@GenerateMocks([
  OnboardingStatusRepository,
  CheckPlatformDevice,
  Permission,
])
void main() {
  group('Startup Service Test', () {
    test('-> execute first time - Android', () async {
      final MockOnboardingStatusRepository mockOnboardingStatusRepository = MockOnboardingStatusRepository();
      final MockCheckPlatformDevice mockCheckPlatformDevice = MockCheckPlatformDevice();
      final MockPermission mockPermission = MockPermission();

      when(mockCheckPlatformDevice.isIos).thenReturn(false);
      when(mockOnboardingStatusRepository.hasToShowOnboarding()).thenAnswer((realInvocation) => Future.value(true));

      final ApplicationStartupService applicationStartupService = ApplicationStartupService(
        mockOnboardingStatusRepository,
        mockCheckPlatformDevice,
        mockPermission,
      );

      final route = await applicationStartupService.execute();

      expect(route, equals(OnboardingScreen.ROUTE));
    });

    test('-> execute second time after onboarding - Android', () async {
      final MockOnboardingStatusRepository mockOnboardingStatusRepository = MockOnboardingStatusRepository();
      final MockCheckPlatformDevice mockCheckPlatformDevice = MockCheckPlatformDevice();
      final MockPermission mockPermission = MockPermission();

      when(mockCheckPlatformDevice.isIos).thenReturn(false);
      when(mockOnboardingStatusRepository.hasToShowOnboarding()).thenAnswer((realInvocation) => Future.value(false));

      final ApplicationStartupService applicationStartupService = ApplicationStartupService(
        mockOnboardingStatusRepository,
        mockCheckPlatformDevice,
        mockPermission,
      );

      final route = await applicationStartupService.execute();

      expect(route, equals(MainScreen.ROUTE));
    });

    test('-> execute first time - iOS - no', () async {
      final MockOnboardingStatusRepository mockOnboardingStatusRepository = MockOnboardingStatusRepository();
      final MockCheckPlatformDevice mockCheckPlatformDevice = MockCheckPlatformDevice();
      final MockPermission mockPermission = MockPermission();

      when(mockCheckPlatformDevice.isIos).thenReturn(true);
      when(mockPermission.isPermanentlyDenied).thenAnswer((realInvocation) => Future.value(false));
      when(mockOnboardingStatusRepository.hasToShowOnboarding()).thenAnswer((realInvocation) => Future.value(true));
      when(mockPermission.request()).thenAnswer((realInvocation) => Future.value(PermissionStatus.granted));

      final ApplicationStartupService applicationStartupService = ApplicationStartupService(
        mockOnboardingStatusRepository,
        mockCheckPlatformDevice,
        mockPermission,
      );

      final route = await applicationStartupService.execute();

      verify(mockCheckPlatformDevice.isIos).called(1);
      verify(mockPermission.isPermanentlyDenied).called(1);
      verify(mockOnboardingStatusRepository.hasToShowOnboarding()).called(1);
      verify(mockPermission.request()).called(1);

      expect(route, equals(OnboardingScreen.ROUTE));
    }, skip: 'Skip ios');
  });
}
